function angle_table( lo, hi, n )
% angle_table( lo, hi, n )
%
% Outputs a table of angles in degrees and radians.
%
% inputs:
%   lo - lower entry in the table (degrees)
%   hi - upper entry in the table (degrees)
%   n  - number of entries in the table
%

degrees = linspace(lo,hi,n);
radians = degrees * pi/180;

fprintf('Degrees   Radians\n');
for i=1:n
  fprintf('%8.2f %8.2f\n',degrees(i),radians(i) );
end
